@@ -166,66 +166,10 @@ const Arg_parser::Option options[] = {
 
 
 CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
-    numberSpaces ( 0 ),
-    lineNrWidth ( 5 ),
-    lineLength ( 80 ),
-    lineNrStart ( 1 ),
-    lineRangeStart( 0 ),
-    lineRangeEnd( 0 ),
-    opt_no_trailing_nl(0),
-    verbosity(0),
-    lsDelay(0),
-    canvasPaddingWidth(0),
-    wrappingStyle ( highlight::WRAP_DISABLED ),
-    outputType ( highlight::HTML ),
-    keywordCase ( StringTools::CASE_UNCHANGED ),
+    
     baseFontSize("10"),
     className ( "hl" ),
-    opt_syntax ( false ),
-    opt_include_style ( false ),
-    opt_help ( false ),
-    opt_version ( false ),
-    opt_print_config ( false ),
-    opt_linenumbers ( false ),
-    opt_batch_mode ( false ),
-    opt_fragment ( false ) ,
-    opt_attach_line_anchors ( false ),
-    opt_printindex ( false ),
-    opt_quiet ( false ),
-    opt_replacequotes ( false ),
-    opt_babel ( false ),
-    opt_beamer ( false ),
-    opt_print_progress ( false ),
-    opt_fill_zeroes ( false ),
-    opt_stylepath_explicit ( false ),
-    opt_force_output ( false ),
-    opt_ordered_list ( false ),
-    opt_fnames_as_anchors ( false ),
-    opt_validate ( false ),
-    opt_number_wrapped_lines ( true ),
-    opt_inline_css ( false ),
-    opt_enclose_pre ( false ),
-    opt_char_styles ( false ),
-    opt_page_color(false),
-    opt_pretty_symbols ( false ),
-    opt_delim_CR (false),
-    opt_print_style(false),
-    opt_base16_theme(false),
-    opt_keep_injections(false),
-    opt_force_stdout(false),
-    opt_no_version_info(false),
-    explicit_output_format(false),
-    opt_isolate(false),
-    opt_encoding_explicit(false),
-    opt_syntax_supported_check(false),
-    opt_service_mode(false),
-    opt_disable_echo(false),
-    opt_ls_hover(false),
-    opt_ls_semantic(false),
-    opt_ls_rainbow(false),
-    opt_ls_syntax_error(false),
-    opt_ls_legacy(false),
-    maxFileSize(268435456),
+    
     fallbackSyntax("txt"),
     anchorPrefix ( "l" ),
     helpLang ( "en" ),
@@ -260,9 +204,9 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
             ignoredFileTypes.insert ( elem );
         }
 
-        std::vector<std::string>::iterator file=inputFileNames.begin();
+        auto file=inputFileNames.begin();
         while ( file!=inputFileNames.end()) {
-            for ( std::set<std::string>::iterator ext=ignoredFileTypes.begin(); ext!=ignoredFileTypes.end(); ext++ ) {
+            for ( auto ext=ignoredFileTypes.begin(); ext!=ignoredFileTypes.end(); ext++ ) {
                 if (file!=inputFileNames.end() && StringTools::endsWith(  *file, *ext )) {
                     file = inputFileNames.erase ( file );
                     break;
@@ -715,7 +659,7 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
                 }
             }
         } else if ( inputFileNames.empty() ) {
-            inputFileNames.push_back ( "" );
+            inputFileNames.emplace_back("" );
         }
     }
 }
