@@ -2,7 +2,7 @@
                           main.cpp  -  description
                              -------------------
     begin                : Die Apr 23 22:16:35 CEST 2002
-    copyright            : (C) 2002-2023 by Andre Simon
+    copyright            : (C) 2002-2024 by Andre Simon
     email                : a.simon@mailbox.org
 
    Highlight is a universal source code to formatted text converter.
@@ -39,6 +39,21 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "syntaxreader.h"
 #include "lspprofile.h"
 
+using std::cerr;
+using std::cin;
+using std::endl;
+using std::flush;
+using std::ifstream;
+using std::istringstream;
+using std::ios;
+using std::map;
+using std::ostream_iterator;
+using std::setiosflags;
+using std::setw;
+using std::string;
+using std::unique_ptr;
+using std::vector;
+
 void HLCmdLineApp::printVersionInfo(bool quietMode)
 {
     if (quietMode) {
@@ -46,11 +61,11 @@ void HLCmdLineApp::printVersionInfo(bool quietMode)
     } else {
         std::cout << "\n highlight version "
             << highlight::Info::getVersion()
-            << "\n Copyright (C) 2002-2023 Andre Simon <a dot simon at mailbox.org>"
+            << "\n Copyright (C) 2002-2025 Andre Simon <a dot simon at mailbox.org>"
             << "\n\n Argparser class"
             << "\n Copyright (C) 2006-2008 Antonio Diaz Diaz <ant_diaz at teleline.es>"
             << "\n\n Artistic Style Classes (" << ASTYLE_VERSION << ")"
-            << "\n Copyright (C) 1998-2023 The Artistic Style Authors"
+            << "\n Copyright (C) 1998-2025 The Artistic Style Authors"
             << "\n\n Diluculum Lua wrapper (1.0)"
             << "\n Copyright (C) 2005-2013 by Leandro Motta Barros"
             << "\n\n xterm 256 color matching functions"
@@ -107,7 +122,7 @@ int HLCmdLineApp::printInstalledFiles(const std::string& where, const std::strin
         categoryFilters.insert ( catFilter );
     }
 
-    for (const auto &path : filePaths ) {
+    for (const auto &path : filePaths) {
         try {
             Diluculum::LuaState ls;
             highlight::SyntaxReader::initLuaState(ls, path,"");
@@ -123,10 +138,10 @@ int HLCmdLineApp::printInstalledFiles(const std::string& where, const std::strin
 
                 categoryMap = ls["Categories"].value().asTable();
 
-                for (Diluculum::LuaValueMap::const_iterator it = categoryMap.begin(); it != categoryMap.end(); ++it)
+                for (const auto &[first, second] : categoryMap)
                 {
-                    categoryNames.insert(it->second.asString());
-                    if (categoryFilters.size() && categoryFilters.count(it->second.asString())) {
+                    categoryNames.insert(second.asString());
+                    if (categoryFilters.size() && categoryFilters.count(second.asString())) {
                         ++filterOKCnt;
                     }
                 }
@@ -139,9 +154,9 @@ int HLCmdLineApp::printInstalledFiles(const std::string& where, const std::strin
                 std::cout << setw ( 30 ) <<setiosflags ( ios::left ) <<desc<<": "<<suffix;
 
                 int extCnt=0;
-                for (StringMap::iterator it=dataDir.assocByExtension.begin(); it!=dataDir.assocByExtension.end(); it++) {
-                    if (it->second==suffix ) {
-                        std::cout << ((++extCnt==1)?" ( ":" ")<<it->first;
+                for (const auto &[first, second] : dataDir.assocByExtension) {
+                    if (second==suffix ) {
+                        std::cout << ((++extCnt==1)?" ( ":" ") << first;
                     }
                 }
                 std::cout << ((extCnt)?" )":"");
@@ -161,8 +176,8 @@ int HLCmdLineApp::printInstalledFiles(const std::string& where, const std::strin
 
         if (!categoryFilters.size()){
             std::cout << "\nFound "<<kind<<" categories:\n\n";
-            for (std::set<string>::iterator it=categoryNames.begin(); it!=categoryNames.end(); ++it)
-                std::cout << *it<< ' ';
+            for ( const auto &catName : categoryNames)
+                std::cout << catName << ' ';
             std::cout << "\n";
         }
 
@@ -189,17 +204,14 @@ void HLCmdLineApp::printDebugInfo ( const highlight::SyntaxReader *lang,
     cerr << "\nLoading language definition:\n" << langDefPath;
     cerr << "\n\nDescription: " << lang->getDescription();
     if (level>1) {
-        Diluculum::LuaState* luaState=lang->getLuaState();
-        if (luaState) {
+
+        if (auto luaState = lang->getLuaState(); luaState) {
             cerr << "\n\nLUA GLOBALS:\n" ;
-            Diluculum::LuaValueMap::iterator it;
-            Diluculum::LuaValueMap glob =luaState->globals();
-            string elemName;
-            for(it = glob.begin(); it != glob.end(); it++) {
-                Diluculum::LuaValue first = it->first;
-                Diluculum::LuaValue second = it->second;
-                elemName = first.asString();
-                std::cerr << elemName<<": ";
+            auto glob = luaState->globals();
+
+            for (const auto &[first, second] : glob) {
+                auto elemName = first.asString();
+                std::cerr << elemName << ": ";
                 switch (second.type()) {
                     case  LUA_TSTRING:
                         cerr << "string [ "<<second.asString()<<" ]";
@@ -217,26 +229,18 @@ void HLCmdLineApp::printDebugInfo ( const highlight::SyntaxReader *lang,
                 }
                 cerr << endl;
             }
-
         }
 
-        highlight::RegexElement *re=NULL;
-        for ( unsigned int i=0; i<lang->getRegexElements().size(); i++ )
-        {
-            if (i==0)
-                cerr << "\nREGEX:\n";
-
-            re = lang->getRegexElements() [i];
-            cerr << "State "<<re->open<< " ("<< HLStateMap[re->open]<<  "):\t"<<re->pattern <<"\n";
+        if (auto regexElements = lang->getRegexElements(); !regexElements.empty()) {
+            std::cerr << "\nREGEX:\n";
+            for (const auto *re : regexElements)
+                std::cerr << "State " << re->open << " (" << HLStateMap[re->open] << "):\t" << re->pattern << "\n";
         }
 
-        highlight::KeywordMap::iterator it;
-        highlight::KeywordMap keys=lang->getKeywords();
-        for ( it=keys.begin(); it!=keys.end(); it++ ) {
-            if (it==keys.begin())
-                cerr << "\nKEYWORDS:\n";
-
-            cerr << " "<< it->first << "("<< it->second << ")";
+        if (auto keys = lang->getKeywords(); !keys.empty()) {
+            std::cerr << "\nKEYWORDS:\n";
+            for (const auto &[keyword, value] : keys)
+                std::cerr << " " << keyword << "(" << value << ")";
         }
     }
     cerr <<"\n\n";
@@ -324,15 +328,16 @@ void HLCmdLineApp::printIOErrorReport ( unsigned int numberErrorFiles,
 vector <string> HLCmdLineApp::collectPluginPaths(const vector<string>& plugins)
 {
     vector<string> absolutePaths;
-    for (unsigned int i=0; i<plugins.size(); i++) {
-        if (Platform::fileExists(plugins[i])) {
-            absolutePaths.push_back(plugins[i]);
+    for (const auto& plugin : plugins) {
+        if (Platform::fileExists(plugin)) {
+            absolutePaths.push_back(plugin);
         } else {
-            absolutePaths.push_back(dataDir.getPluginPath(plugins[i]+".lua"));
+            absolutePaths.push_back(dataDir.getPluginPath(plugin + ".lua"));
         }
     }
     return absolutePaths;
 }
+
 bool HLCmdLineApp::serviceModeCheck(CmdLineOptions &options, highlight::CodeGenerator* generator, string &suffix, unsigned int &curFileIndex){
     if (! options.runServiceMode())
         return false;
@@ -393,7 +398,7 @@ bool HLCmdLineApp::serviceModeCheck(CmdLineOptions &options, highlight::CodeGene
                 options.getLineLength() - options.getNumberWidth() : options.getLineLength(),
                 options.getNumberSpaces());
         } else if (modeKey == "eof") {
-            unsigned char eof = (unsigned char)modeVal[0];
+            auto eof = modeVal.size() && (unsigned char)modeVal[0];
             generator->setAdditionalEOFChar(eof);
             modeRes += "eof char val: " + std::to_string(eof) + " ";
         } else if (modeKey == "tag") {
@@ -585,13 +590,13 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
 
     bool styleFileWanted = !options.fragmentOutput() || options.styleOutPathDefined();
 
-    const  vector <string> pluginFileList=collectPluginPaths( options.getPluginPaths());
-    for (unsigned int i=0; i<pluginFileList.size(); i++) {
-        if ( !generator->initPluginScript(pluginFileList[i]) ) {
+    const vector <string> pluginFileList=collectPluginPaths( options.getPluginPaths());
+    for (const auto& pluginFile : pluginFileList) {
+        if ( !generator->initPluginScript(pluginFile) ) {
             cerr << "highlight: "
                  << generator->getPluginScriptError()
                  << " in "
-                 << pluginFileList[i]
+                 << pluginFile
                  <<"\n";
             return EXIT_FAILURE;
         }
@@ -835,9 +840,18 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
 
         if ( options.enableBatchMode() ) {
             if (usedFileNames.count(inFileName)) {
-                string prefix=inFileList[i].substr (2, pos-1 );
-                replace (prefix.begin(), prefix.end(), Platform::pathSeparator, '_');
-                inFileName.insert(0, prefix);
+                string prefix = inFileList[i].substr(0, pos);
+                // ignore dots in path
+                prefix.erase(std::remove(prefix.begin(), prefix.end(), '.'), prefix.end());
+                // replace path separators with underscores to create a flat prefix
+                std::replace(prefix.begin(), prefix.end(), Platform::pathSeparator, '_');
+                // remove leading underscore if any
+                if (!prefix.empty() && prefix[0] == '_') {
+                    prefix.erase(0, 1);
+                }
+                if (!prefix.empty()) {
+                    inFileName.insert(0, prefix + "_");
+                }
             } else {
                 usedFileNames.insert(inFileName);
             }
