@@ -26,6 +26,9 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "xhtmlgenerator.h"
 
+using std::string;
+using std::ostringstream;
+
 namespace highlight
 {
 
@@ -69,7 +72,7 @@ string XHtmlGenerator::getHeader()
                 os << "]]>\n";
                 os << "</style>\n";
             } else {
-                os << "<link rel=\"stylesheet\" type=\"text/css\" href=\""
+                os << R"(<link rel="stylesheet" type="text/css" href=")"
                    << getStyleOutputPath()
                    << "\""
                    << "/"
